Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1342)

Unified Diff: content/public/browser/plugin_service_filter.h

Issue 12209008: Follow-on fixes and naming changes for https://codereview.chromium.org/12086077/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/renderer_host/render_message_filter.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/plugin_service_filter.h
===================================================================
--- content/public/browser/plugin_service_filter.h (revision 180620)
+++ content/public/browser/plugin_service_filter.h (working copy)
@@ -20,16 +20,16 @@
public:
virtual ~PluginServiceFilter() {}
// Whether |plugin| is enabled. The client can return false to hide the
// plugin, or return true and optionally change the passed in plugin.
- virtual bool IsPluginEnabled(int render_process_id,
- int render_view_id,
- const void* context,
- const GURL& url,
- const GURL& policy_url,
- webkit::WebPluginInfo* plugin) = 0;
+ virtual bool IsPluginAvailable(int render_process_id,
+ int render_view_id,
+ const void* context,
+ const GURL& url,
+ const GURL& policy_url,
+ webkit::WebPluginInfo* plugin) = 0;
- // Whether the renderer has permission to load enabled |plugin|.
+ // Whether the renderer has permission to load available |plugin|.
virtual bool CanLoadPlugin(int render_process_id,
const FilePath& path) = 0;
};
@@ -20,16 +20,16 @@
public:
virtual ~PluginServiceFilter() {}
- // Whether |plugin| is enabled. The client can return false to hide the
+ // Whether |plugin| is available. The client can return false to hide the
// plugin, or return true and optionally change the passed in plugin.
« no previous file with comments | « content/browser/renderer_host/render_message_filter.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698